@@ -27,9 +27,12 @@
 """
 from __future__ import annotations
 
+from typing import IO
+
 from . import ImageFile, ImagePalette, UnidentifiedImageError
 from ._binary import i16be as i16
 from ._binary import i32be as i32
+from ._typing import StrOrBytesPath
 
 
 class GdImageFile(ImageFile.ImageFile):
@@ -43,8 +46,10 @@ class GdImageFile(ImageFile.ImageFile):
     format = "GD"
     format_description = "GD uncompressed images"
 
-    def _open(self):
+    def _open(self) -> None:
         # Header
+        assert self.fp is not None
+
         s = self.fp.read(1037)
 
         if i16(s) not in [65534, 65535]:
@@ -67,7 +72,7 @@ class GdImageFile(ImageFile.ImageFile):
         )
 
         self.tile = [
-            (
+            ImageFile._Tile(
                 "raw",
                 (0, 0) + self.size,
                 7 + true_color_offset + 4 + 256 * 4,
@@ -76,7 +81,7 @@ class GdImageFile(ImageFile.ImageFile):
         ]
 
 
-def open(fp, mode="r"):
+def open(fp: StrOrBytesPath | IO[bytes], mode: str = "r") -> GdImageFile:
     """
     Load texture from a GD image file.
 
